@@ -192,10 +192,8 @@ class Customer(object):
         import time
         url = core.database_url(**FUPDB_CREDENTIALS)
         LOGS.logger.warn('last date {} de {}'.format(last_date, self.name))
-        LOGS.logger.debug("trace de {}".format(self.name))
         OK = False
         for i in range(3):
-            LOGS.logger.debug("essai {} de {}".format(i, self.name))
             if OK:
                 break
             try:
@@ -210,7 +208,7 @@ class Customer(object):
                 if response:
                     OK = True
             except requests.exceptions.ConnectTimeout:
-                LOGS.logger.debug("essai ERROR {} de {}".format(i, self.name))
+                LOGS.logger.info("essai ERROR {} de {}".format(i, self.name))
                 time.sleep(60)
                 continue
         infos = response['content']
